# :rocket: WaterRocket
[![Python](https://img.shields.io/pypi/pyversions/tensorflow.svg?style=plastic)](https://pypi.org/project/WaterRocket/0.1/) [![PyPI](https://badge.fury.io/py/WaterRocket.svg)](https://pypi.org/project/WaterRocket/0.1/)
WaterRocket is an easy to use and intuitive Python module made for the simulation of amateur water rocket shooting based on water bottles or lemonade. This module follows the project of design and instrumentation of a water rocket in the framework of the Erasmus + exchange program between Polytech Paris-Saclay and Ecole Nationale Polytechnique. This project is inspired by a work done previously in the form of an Excel file (the simulator file V1.xls) made by ...
## Getting started
```
$ pip install WaterRocket
```
Then to use all the functions you have to create a WaterRocket object : 
```python
from WaterRocket import WaterRocket

myRocket = WaterRocket()
```
For a getting started Notebook example click [here](./examples/getting_started.ipynb)
## Documentation 
All the documentation about the module methods and components describe [here](documentation.md)
## Creator and maintainer
Mohamed Nennouche